==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/prediction_service/prediction_service_get_portfolio.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.portfolio_prediction import PortfolioPrediction
from ...models.portfolio_prediction_bad_request import PortfolioPredictionBadRequest
from ...models.portfolio_prediction_error import PortfolioPredictionError
from ...models.portfolio_prediction_not_found import PortfolioPredictionNotFound
from ...models.portfolio_prediction_request import PortfolioPredictionRequest
from ...models.portfolio_prediction_unauthorized import PortfolioPredictionUnauthorized
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: PortfolioPredictionRequest,
) -> Dict[str, Any]:
    url = "{}/api/v1/predictions/portfolio/latest".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    if response.status_code == 200:
        response_200 = PortfolioPrediction.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = PortfolioPredictionBadRequest.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = PortfolioPredictionUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PortfolioPredictionNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PortfolioPredictionError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: PortfolioPredictionRequest,
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: PortfolioPredictionRequest,
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    """
    Weighted aggregate of the prepayment prediction of the portfolio components for an as-of date, default to today.

    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: PortfolioPredictionRequest,
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: PortfolioPredictionRequest,
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    """ Weighted aggregate of the prepayment prediction of the portfolio components for an as-of date, default to today. """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> infima_client-0.259.0-py3-none-any.whl: infima_client/api/prediction_service/prediction_service_get_portfolio.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.portfolio_prediction import PortfolioPrediction
from ...models.portfolio_prediction_bad_request import PortfolioPredictionBadRequest
from ...models.portfolio_prediction_error import PortfolioPredictionError
from ...models.portfolio_prediction_not_found import PortfolioPredictionNotFound
from ...models.portfolio_prediction_unauthorized import PortfolioPredictionUnauthorized
from ...models.prediction_service_get_portfolio_json_body import (
    PredictionService_GetPortfolioJsonBody,
)
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioJsonBody,
) -> Dict[str, Any]:
    url = "{}/api/v1/predictions/portfolio/latest".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    if response.status_code == 200:
        response_200 = PortfolioPrediction.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = PortfolioPredictionBadRequest.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = PortfolioPredictionUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PortfolioPredictionNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PortfolioPredictionError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioJsonBody,
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioJsonBody,
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    """
    Weighted aggregate of the prepayment prediction of the portfolio components for an as-of date, default to today.

    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioJsonBody,
) -> Response[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioJsonBody,
) -> Optional[
    Union[
        PortfolioPrediction,
        PortfolioPredictionBadRequest,
        PortfolioPredictionUnauthorized,
        PortfolioPredictionNotFound,
        PortfolioPredictionError,
    ]
]:
    """ Weighted aggregate of the prepayment prediction of the portfolio components for an as-of date, default to today. """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
